============================
{{pkg_name}} v |version|
============================

About
=====



Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   getting_started
   reference/index
